@@ -1,6 +1,8 @@
 package App::podispell;
-our $VERSION = '0.001002';
-$VERSION = eval $VERSION;
+use strict;
+use warnings;
+our $VERSION = '0.001003';
+$VERSION =~ tr/_//d;
 1;
 __END__
 
